#!/bin/bash

set -e

P=opencl
V=2.0.10
B=3

# override msys
cat() { /bin/cat "$@"; }
cp() { /bin/cp "$@"; }
rm() { /bin/rm "$@"; }
mkdir() { /bin/mkdir "$@"; }
tar() { /bin/tar "$@"; }
ls() { /bin/ls "$@"; }
sed() { /bin/sed "$@"; }
diff() { /bin/diff "$@"; }
declare -x cat cp rm mkdir tar ls sed diff

D=$PWD
export ARCH=$1


wget -q -O - https://github.com/KhronosGroup/OpenCL-Headers/archive/master.tar.gz | tar --xform s,OpenCL-Headers-master/LICENSE,$P-$V-$B.txt, --xform s,OpenCL-Headers-master/,include/, -xzvf - OpenCL-Headers-master/LICENSE OpenCL-Headers-master/CL/
wget -q -O include/CL/cl2.hpp https://github.com/KhronosGroup/OpenCL-CLHPP/releases/download/v2.0.10/cl2.hpp

for ARCH in x86_64 x86; do
	R=../../../$ARCH/release/$P

	mkdir -p $R $R/$P-devel
	cp $P-$V-$B.txt $R

cat <<EOF >$R/$P-devel/setup.hint
sdesc: "KhronosGroup OpenCL development files"
ldesc: "KhronosGroup OpenCL development files"
maintainer: JuergenFischer
category: Libs
requires: $P
EOF

cat <<EOF >$R/setup.hint
sdesc: "KhronosGroup OpenCL runtime"
ldesc: "KhronosGroup OpenCL runtime"
maintainer: JuergenFischer
category: Libs
external-source: opencl-devel
requires: msvcrt
EOF

	mkdir -p lib bin etc/postinstall etc/preremove
	cp opencl-$ARCH.lib lib/opencl.lib
	cp opencl-$ARCH.dll bin/opencl.dll

cat <<EOF >etc/postinstall/$P.bat
dllupdate -copy -reboot "%OSGEO4W_ROOT%\bin\opencl.dll"
EOF

cat <<EOF >etc/preremove/$P.bat
dllupdate -unref -reboot "%OSGEO4W_ROOT%\bin\opencl.dll"
EOF

	tar cjf $R/$P-devel/$P-devel-$V-$B.tar.bz2 include/CL lib/opencl.lib
	tar cjf $R/$P-$V-$B.tar.bz2 bin/opencl.dll etc/postinstall/ etc/preremove/

	tar -C .. -cjf $R/$P-$V-$B-src.tar.bz2 \
		osgeo4w/package.sh \
		osgeo4w/opencl-x86.lib \
		osgeo4w/opencl-x86.dll \
		osgeo4w/opencl-x86_64.lib \
		osgeo4w/opencl-x86_64.dll
done
